@@ -4,7 +4,7 @@ package WWW::Search::Scraper::computerjobs;
 use strict;
 use vars qw($VERSION @ISA);
 @ISA = qw(WWW::Search::Scraper);
-$VERSION = sprintf("%d.%02d", q$Revision: 1.12 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 1.13 $ =~ /(\d+)\.(\d+)/);
 use WWW::Search::Scraper(qw(1.48 trimLFs testParameters));
 
 my $scraperRequest = 
@@ -73,7 +73,7 @@ sub testParameters {
     }
     
     return { 
-             'SKIP' => 'something wrong here, I don\'t know what it is.'
+             'SKIP' => 'computerjobs - something wrong here, I don\'t know what it is.'
             ,'testNativeQuery' => 'Perl'
             ,'expectedOnePage' => 9
             ,'expectedMultiPage' => 11
